  * {
    font-size: 1em;
  }

  .container {
    height: 95vh;
    display: grid; 
    grid-template-columns: min-content min-content 1fr;
    grid-template-rows: min-content min-content min-content auto min-content; 
    gap: 0px 0px; 
    grid-template-areas: 
      "info hostlist custom"
      "info chartlist custom"
      "info activities custom"
      "chart chart chart"
      "footer footer footer"; 
  }
  .hostlist { grid-area: hostlist; }
  .info { grid-area: info; }
  .chartlist { grid-area: chartlist; }
  .activities { grid-area: activities; }
  .custom { grid-area: custom; }
  .chart { grid-area: chart; }
  .footer { grid-area: footer; }

  .container {
    padding: 0.3em;
    border: 1px solid #ccc;
    border-radius: 10px;
    margin-bottom: 5px;
  }
  
  .info {
    justify-self: center;
    align-self: start;
    width: min-content;
    text-wrap: nowrap;
    padding: 0em 1em;
    }
  
  .hostlist { 
    justify-self: left;
    align-self: start;
  }
  
  .chartlist { 
    justify-self: left;
    align-self: start;
  }
  
  .activities { 
    justify-self: left;
    align-self: start;
  }
  
  .custom { 
    width: 100%;
    justify-self: left;
    align-self: start;
  }

  div.chart {
    padding: 5px;
    border: 1px solid #ccc;
    border-radius: 10px;
    margin-bottom: 5px;
  }

  .footer {
    padding: 0.3em;
    background-color: #eee;
    border: solid 1px #000;
    border-radius: 5px;
  }

  div.activities ul, div.info ul, div.hostlist ul, div.chartlist ul  {
    padding: 0;
    margin: 0;
    list-style-type: none;
  }

  div.activities ul {
    display: flex;
    flex-wrap: wrap;
  }
  div.activities ul li {
    display: inline;
    padding: 0.3em;
    border: 1px solid #ccc;    
    border-radius: 5px;
    margin-bottom: 5px;
    margin-left: 0.2em;
  }
  a:link, a:visited,  a:active {
    color: #5685bc;
    text-decoration: none;
  }
  a:hover {
    color:rgba(255, 0, 0, 0.650);
    text-decoration: none;
  }
  li.active {
    background-color: #eee;
  }
  li.inactive {
    background-color: #fff;
  }  
  li.disabled {
    color: #ccc;
    background-color: #fff;
  }
  li.i_active {
    background-color: #eee;
  }
  li.i_inactive {
    background-color: #fff;
  }  
  li.i_disabled {
    color: #ccc;
    background-color: #fff;
  }
  .zg-ul-select:not(.active)::after {
    background-image: url('../img/chevron.svg');
  }
  #eventname, #eventdescription {
    display: none;
  }
  #copyright {
    width: 20%;
    border-bottom: 1px solid #5685bc;
    border-top: 1px solid #5685bc;
    font-size: 0.72em;
    font-weight: bold;
    margin: 0em auto 0em auto;
    padding: 0.1em;
    text-align: center;
  }
  #eventname {
    width: 35%;
    font-weight: bold;
    font-family: monospace;
    border-bottom: 1px solid #5685bc;
    border-top: 1px solid #5685bc;
    margin: 0em auto 0em auto;
    padding: 0.1em;
    text-align: center;
  }
  #eventdescription {
    margin-top: 0.5em;
    font-family: monospace;
    white-space: pre;
  }
  #eventdemo {
    width: max-content;
    margin: 0em auto 0em auto;
    background-color: #ddd;
    border: dashed 1px #000;
    border-radius: 1em;
    padding: 0.5em;
    color: #000;
  }
  .extrametrics {
    display: grid;
    overflow: hidden;
    overflow-y: auto;
    max-height: 6em;
  }

  .extrametrics label {
    width: fit-content;
  }